#!/bin/sh
set -ev

ROOT=$(dirname $(dirname $(realpath "${0}")))

# Build documentation
cd ${ROOT}/doc
make html

# Build basic tar
cd ${ROOT}/vm
tar czpf /srv/build/vm.tar.gz *

# Build native apps
cd ${ROOT}/apk/geos
apk add -U swig python2-dev
abuild -F

cd ${ROOT}/apk/gdal
apk add -U curl-dev geos-dev@vm giflib-dev jpeg-dev libjpeg-turbo-dev libpng-dev linux-headers postgresql-dev python2-dev sqlite-dev swig tiff-dev zlib-dev
abuild -F

cd ${ROOT}/apk/proj4
abuild -F

cd ${ROOT}/apk/rabbitmq-server
apk add -U elixir erlang-compiler erlang-dev erlang-edoc erlang-eldap erlang-erl-docgen erlang-mnesia erlang-os-mon erlang-runtime-tools erlang-tools erlang-xmerl gawk grep libxslt py2-simplejson python2 rsync socat xmlto zip
abuild -F

cd ${ROOT}/apk/postgis
apk add -U gdal-dev@vm geos-dev@vm json-c-dev libxml2-dev pcre-dev perl perl-dev postgresql postgresql-dev proj4-dev@vm
abuild -F

cd ${ROOT}/apk/vmmgr
abuild -F

cd ${ROOT}/apk/wireguard
apk add -U libmnl-dev linux-virt-dev linux-firmware-none
FLAVOR=virt abuild -F

cd ${ROOT}/apk/wireguard-tools
apk add -U libmnl-dev
abuild -F

# Build runtimes
cd ${ROOT}/lxc-shared
spoc-image build -p alpine3.8/image
spoc-image build -p alpine3.8-php5.6/image
spoc-image build -p alpine3.8-ruby2.4/image
spoc-image build -p alpine3.9/image
spoc-image build -p alpine3.9-java8/image
spoc-image build -p alpine3.9-php7.2/image
spoc-image build -p alpine3.9-python2.7/image
spoc-image build -p alpine3.9-python3.6/image
spoc-image build -p alpine3.9-ruby2.4/image
spoc-image build -p alpine3.9-ruby2.6/image
spoc-image build -p alpine3.9-tomcat7/image
spoc-image build -p alpine3.9-tomcat8.5/image

# Build services
cd ${ROOT}/lxc-services
spoc-image build -p activemq/image
spoc-image build -p mariadb/image
spoc-image build -p postgres/image
spoc-image build -p postgis/image
spoc-image build -p rabbitmq/image
spoc-image build -p redis/image
spoc-image build -p solr6/image

# Build applications
cd ${ROOT}/lxc-apps

spoc-image build -p ckan/image
spoc-image build -p ckan-datapusher/image
spoc-app publish ckan/app

spoc-image build -p crisiscleanup/image
spoc-app publish crisiscleanup/app

spoc-image build -p cts/image
spoc-app publish cts/app

spoc-image build -p decidim/image
spoc-app publish decidim/app

spoc-image build -p ecogis/image
# spoc-app publish ecogis/app

spoc-image build -p frontlinesms/image
spoc-app publish frontlinesms/app

spoc-image build -p gnuhealth/image
spoc-app publish gnuhealth/app

spoc-image build -p kanboard/image
spoc-app publish kanboard/app

spoc-image build -p mifosx/image
spoc-app publish mifosx/app

spoc-image build -p motech/image
spoc-app publish motech/app

spoc-image build -p odoo/image
spoc-app publish odoo/app

spoc-image build -p opendatakit/image
spoc-image build -p opendatakit-build/image
spoc-app publish opendatakit/app

spoc-image build -p openmapkit/image
spoc-app publish openmapkit/app

spoc-image build -p pandora/image
spoc-app publish pandora/app

spoc-image build -p sahana/image
spoc-app publish sahana/app
spoc-app publish sahana-demo/app
spoc-app publish sambro/app

spoc-image build -p seeddms/image
spoc-app publish seeddms/app

spoc-image build -p sigmah/image
spoc-app publish sigmah/app

spoc-image build -p ushahidi/image
spoc-app publish ushahidi/app
