#!/bin/sh
set -ev

# Create containers
spoc-container create \
    -m sahana-demo/postgres_data:var/lib/postgresql \
    sahana-demo-postgres postgis_3.0.0-200207
spoc-container create \
    -d sahana-demo-postgres \
    -m sahana-demo/sahana_conf:srv/web2py/applications/eden/models \
    -m sahana-demo/sahana_data/default:srv/web2py/applications/eden/modules/templates/default \
    -m sahana-demo/sahana_data/databases:srv/web2py/applications/eden/databases \
    -m sahana-demo/sahana_data/uploads:srv/web2py/applications/eden/uploads \
    sahana-demo sahana_0.0.1-200207

# TODO: Populate from spoc
LAYER_DIR="/var/lib/spoc/layers"
VOLUME_DIR="/var/lib/spoc/volumes/sahana-demo"
POSTGRES_UID=70
POSTGRES_GID=70
POSTGRES_NSUID=100070
POSTGRES_NSGID=100070
SAHANA_UID=103
SAHANA_GID=104
SAHANA_NSUID=100103
SAHANA_NSGID=100104

# Create Postgres instance
mkdir -p ${VOLUME_DIR}/postgres_data
chown -R ${POSTGRES_NSUID}:${POSTGRES_NSGID} ${VOLUME_DIR}/postgres_data
chmod 700 ${VOLUME_DIR}/postgres_data
spoc-container exec sahana-demo-postgres -- initdb -D /var/lib/postgresql

# Configure Postgres
cp postgres_data/postgresql.conf ${VOLUME_DIR}/postgres_data/postgresql.conf
cp postgres_data/pg_hba.conf ${VOLUME_DIR}/postgres_data/pg_hba.conf

# Create PostgreSQL user and database
export SAHANADEMO_PWD=$(head -c 18 /dev/urandom | base64 | tr -d '+/=')
spoc-container start sahana-demo-postgres
envsubst <createdb.sql | spoc-container exec sahana-demo-postgres -- psql

# Prepare persistent directory structure
mkdir -p ${VOLUME_DIR}/sahana_data/databases ${VOLUME_DIR}/sahana_data/uploads
chown -R ${SAHANA_NSUID}:${SAHANA_NSGID} ${VOLUME_DIR}/sahana_data
cp -rp ${LAYER_DIR}/sahana_0.0.1-200207/srv/web2py/applications/eden/models ${VOLUME_DIR}/sahana_conf
cp -rp ${LAYER_DIR}/sahana_0.0.1-200207/srv/web2py/applications/eden/modules/templates/default ${VOLUME_DIR}/sahana_data/default

# Configure Sahana
export SAHANADEMO_HMAC=$(head -c 18 /dev/urandom | base64 | tr -d '+/=')
export SAHANADEMO_ADMIN_USER=admin@example.com
export SAHANADEMO_ADMIN_PWD=$(head -c 12 /dev/urandom | base64 | tr -d '+/=')
envsubst <sahana_conf/000_config.py >${VOLUME_DIR}/sahana_conf/000_config.py
envsubst <masterUsers.csv >${VOLUME_DIR}/sahana_data/default/users/masterUsers.csv
chown -R ${SAHANA_NSUID}:${SAHANA_NSGID} ${VOLUME_DIR}/sahana_conf ${VOLUME_DIR}/sahana_data

# Populate database
spoc-container exec -u sahana sahana-demo -- sh -c 'cd /srv/web2py; ./web2py.py -S eden -M -R applications/eden/static/scripts/tools/noop.py'

# Install config update script
cp update-conf.sh ${VOLUME_DIR}/update-conf.sh

# Stop services required for setup
spoc-container stop sahana-demo-postgres

# Register application
#vmmgr register-app sahana-demo sahana-demo "${SAHANADEMO_ADMIN_USER}" "${SAHANADEMO_ADMIN_PWD}"
