#!/bin/sh
set -ev

# Create containers
spoc-container create \
    -m sahana/postgres_data:var/lib/postgresql \
    sahana-postgres postgis_3.0.0-200207
spoc-container create \
    -d sahana-postgres \
    -m sahana/sahana_conf:srv/web2py/applications/eden/models \
    -m sahana/sahana_data/Spotter:srv/web2py/applications/eden/modules/templates/Spotter \
    -m sahana/sahana_data/databases:srv/web2py/applications/eden/databases \
    -m sahana/sahana_data/uploads:srv/web2py/applications/eden/uploads \
    sahana sahana_0.0.1-200207

# TODO: Populate from spoc
LAYER_DIR="/var/lib/spoc/layers"
VOLUME_DIR="/var/lib/spoc/volumes/sahana"
POSTGRES_UID=70
POSTGRES_GID=70
POSTGRES_NSUID=100070
POSTGRES_NSGID=100070
SAHANA_UID=103
SAHANA_GID=104
SAHANA_NSUID=100103
SAHANA_NSGID=100104

# Create Postgres instance
mkdir -p ${VOLUME_DIR}/postgres_data
chown -R ${POSTGRES_NSUID}:${POSTGRES_NSGID} ${VOLUME_DIR}/postgres_data
chmod 700 ${VOLUME_DIR}/postgres_data
spoc-container exec sahana-postgres -- initdb -D /var/lib/postgresql

# Configure Postgres
cp postgres_data/postgresql.conf ${VOLUME_DIR}/postgres_data/postgresql.conf
cp postgres_data/pg_hba.conf ${VOLUME_DIR}/postgres_data/pg_hba.conf

# Create PostgreSQL user and database
export SAHANA_PWD=$(head -c 18 /dev/urandom | base64 | tr -d '+/=')
spoc-container start sahana-postgres
envsubst <createdb.sql | spoc-container exec sahana-postgres -- psql

# Prepare persistent directory structure
mkdir -p ${VOLUME_DIR}/sahana_data/databases ${VOLUME_DIR}/sahana_data/uploads
chown -R ${SAHANA_NSUID}:${SAHANA_NSGID} ${VOLUME_DIR}/sahana_data
cp -rp ${LAYER_DIR}/sahana_0.0.1-200207/srv/web2py/applications/eden/models ${VOLUME_DIR}/sahana_conf

# Copy Spotter template
cp -r sahana_data/Spotter ${VOLUME_DIR}/sahana_data/
chown -R ${SAHANA_NSUID}:${SAHANA_NSGID} ${VOLUME_DIR}/sahana_data

# Configure Sahana
export SAHANA_HMAC=$(head -c 18 /dev/urandom | base64 | tr -d '+/=')
export SAHANA_ADMIN_USER=admin@example.com
export SAHANA_ADMIN_PWD=$(head -c 12 /dev/urandom | base64 | tr -d '+/=')
envsubst <sahana_conf/000_config.py >${VOLUME_DIR}/sahana_conf/000_config.py
envsubst <sahana_data/Spotter/masterUsers.csv >${VOLUME_DIR}/sahana_data/Spotter/masterUsers.csv
cp sahana_conf/00_settings.py ${VOLUME_DIR}/sahana_conf/00_settings.py
chown -R ${SAHANA_NSUID}:${SAHANA_NSGID} ${VOLUME_DIR}/sahana_conf ${VOLUME_DIR}/sahana_data

# Populate database
spoc-container exec -u sahana sahana -- sh -c 'cd /srv/web2py; ./web2py.py -S eden -M -R applications/eden/static/scripts/tools/noop.py'

# Set "production values" (increases performance) only if the DEBUG environment variable is not set
if [ ${DEBUG:-0} -eq 0 ]; then
    sed -i 's/settings.base.migrate = True/settings.base.migrate = False/' ${VOLUME_DIR}/sahana_conf/000_config.py
    sed -i 's/settings.base.debug = True/settings.base.debug = False/' ${VOLUME_DIR}/sahana_conf/000_config.py
    sed -i 's/#settings.base.prepopulate = 0/settings.base.prepopulate = 0/' ${VOLUME_DIR}/sahana_conf/000_config.py
fi

# Install config update script
cp update-conf.sh ${VOLUME_DIR}/update-conf.sh

# Stop services required for setup
spoc-container stop sahana-postgres

# Register application
#vmmgr register-app sahana sahana "${SAHANA_ADMIN_USER}" "${SAHANA_ADMIN_PWD}"
